@@ -1,7 +1,7 @@
 package Complete::Fish;
 
-our $DATE = '2015-09-09'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2016-10-21'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -22,48 +22,6 @@ $SPEC{':package'} = {
     summary => 'Completion module for fish shell',
 };
 
-$SPEC{parse_cmdline} = {
-    v => 1.1,
-    summary => 'Parse shell command-line for processing by completion routines',
-    description => <<'_',
-
-This function converts COMMAND_LINE (str) given by tcsh to become something like
-COMP_WORDS (array) and COMP_CWORD (int), like what bash supplies to shell
-functions. Currently implemented using `Complete::Bash`'s `parse_cmdline`.
-
-_
-    args_as => 'array',
-    args => {
-        cmdline => {
-            summary => 'Command-line, defaults to COMMAND_LINE environment',
-            schema => 'str*',
-            pos => 0,
-        },
-    },
-    result => {
-        schema => ['array*', len=>2],
-        description => <<'_',
-
-Return a 2-element array: `[$words, $cword]`. `$words` is array of str,
-equivalent to `COMP_WORDS` provided by bash to shell functions. `$cword` is an
-integer, equivalent to `COMP_CWORD` provided by bash to shell functions. The
-word to be completed is at `$words->[$cword]`.
-
-Note that COMP_LINE includes the command name. If you want the command-line
-arguments only (like in `@ARGV`), you need to strip the first element from
-`$words` and reduce `$cword` by 1.
-
-_
-    },
-    result_naked => 1,
-};
-sub parse_cmdline {
-    my ($line) = @_;
-
-    $line //= $ENV{COMMAND_LINE};
-    Complete::Bash::parse_cmdline($line, length($line));
-}
-
 $SPEC{format_completion} = {
     v => 1.1,
     summary => 'Format completion for output (for shell)',
@@ -145,7 +103,7 @@ Complete::Fish - Completion module for fish shell
 
 =head1 VERSION
 
-This document describes version 0.04 of Complete::Fish (from Perl distribution Complete-Fish), released on 2015-09-09.
+This document describes version 0.05 of Complete::Fish (from Perl distribution Complete-Fish), released on 2016-10-21.
 
 =head1 DESCRIPTION
 
@@ -177,11 +135,13 @@ Format completion for output (for shell).
 fish accepts completion reply in the form of one entry per line to STDOUT.
 Description can be added to each entry, prefixed by tab character.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<completion>* => I<hash|array>
+=item * B<$completion>* => I<hash|array>
 
 Completion answer structure.
 
@@ -191,45 +151,6 @@ Either an array or hash, as described in C<Complete>.
 
 Return value: Formatted string (or array, if `as` key is set to `array`) (str|array)
 
-
-=head2 parse_cmdline($cmdline) -> array
-
-Parse shell command-line for processing by completion routines.
-
-This function converts COMMAND_LINE (str) given by tcsh to become something like
-COMP_WORDS (array) and COMP_CWORD (int), like what bash supplies to shell
-functions. Currently implemented using C<Complete::Bash>'s C<parse_cmdline>.
-
-Arguments ('*' denotes required arguments):
-
-=over 4
-
-=item * B<cmdline> => I<str>
-
-Command-line, defaults to COMMAND_LINE environment.
-
-=back
-
-Return value:  (array)
-
-
-Return a 2-element array: C<[$words, $cword]>. C<$words> is array of str,
-equivalent to C<COMP_WORDS> provided by bash to shell functions. C<$cword> is an
-integer, equivalent to C<COMP_CWORD> provided by bash to shell functions. The
-word to be completed is at C<< $words-E<gt>[$cword] >>.
-
-Note that COMP_LINE includes the command name. If you want the command-line
-arguments only (like in C<@ARGV>), you need to strip the first element from
-C<$words> and reduce C<$cword> by 1.
-
-=head1 SEE ALSO
-
-L<Complete>
-
-L<Complete::Bash>
-
-Fish manual.
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Complete-Fish>.
@@ -246,13 +167,21 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Complete>
+
+L<Complete::Bash>
+
+Fish manual.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
